package ezc.tests;

import static org.junit.Assert.*;

import java.io.IOException;
import java.io.StringReader;
import java.util.ArrayList;

import org.junit.Test;

import ezc.model.Annuncio;
import ezc.model.TipoAnnuncio;
import ezc.model.TipologiaImmobile;
import ezc.persistence.AnnunciFormatException;
import ezc.persistence.MyAnnunciReader;

public class MyAnnunciReaderTests
{
	@Test
	public void testRead() throws IOException, AnnunciFormatException
	{
		StringReader reader = new StringReader(
				"13/09/2011 : V20688191: monolocale: 25: monolocale interno con angolo cottura, un bagno, termo autonomo: saffi: bologna: 77000\n"+
				"10/09/2011 : A00080198: monolocale: 25: monolocale con angolo cottura, un bagno, termo autonomo, spese escluse: saffi: bologna: 400\n");
		
		ArrayList<Annuncio> annunci = new ArrayList<Annuncio>(new MyAnnunciReader().read(reader));
		
		Annuncio a = annunci.get(0);
		assertEquals(TipoAnnuncio.VENDITA, a.getTipo());
		assertEquals("V20688191", a.getCodice());
		assertEquals(TipologiaImmobile.MONOLOCALE, a.getTipologia());
		assertEquals(25, a.getMq());
		assertEquals("monolocale interno con angolo cottura, un bagno, termo autonomo", a.getDescrizione());
		assertEquals("saffi", a.getZona());
		assertEquals("bologna", a.getCitta());
		assertEquals(77000, a.getRichiesta());
		
		a = annunci.get(1);
		assertEquals(TipoAnnuncio.AFFITTO, a.getTipo());
		assertEquals("A00080198", a.getCodice());
		assertEquals(TipologiaImmobile.MONOLOCALE, a.getTipologia());
		assertEquals(25, a.getMq());
		assertEquals("monolocale con angolo cottura, un bagno, termo autonomo, spese escluse", a.getDescrizione());
		assertEquals("saffi", a.getZona());
		assertEquals("bologna", a.getCitta());
		assertEquals(400, a.getRichiesta());
	}
	
	@Test(expected=AnnunciFormatException.class)
	public void testReadFail0() throws IOException, AnnunciFormatException
	{
		StringReader reader = new StringReader(
				"13/09/AA11 : V20688191: monolocale: 25: monolocale interno con angolo cottura, un bagno, termo autonomo: saffi: bologna: 77000\n");
		
		new MyAnnunciReader().read(reader);
	}
	
	@Test(expected=AnnunciFormatException.class)
	public void testReadFail1() throws IOException, AnnunciFormatException
	{
		StringReader reader = new StringReader(
				"13/09/2011 : X20688191: monolocale: 25: monolocale interno con angolo cottura, un bagno, termo autonomo: saffi: bologna: 77000\n");
		
		new MyAnnunciReader().read(reader);
	}
	
	@Test(expected=AnnunciFormatException.class)
	public void testReadFail2() throws IOException, AnnunciFormatException
	{
		StringReader reader = new StringReader(
				"13/09/2011 : A20688191: trilo: 25: monolocale interno con angolo cottura, un bagno, termo autonomo: saffi: bologna: 77000\n");
		
		new MyAnnunciReader().read(reader);
	}
	
	@Test(expected=AnnunciFormatException.class)
	public void testReadFail3() throws IOException, AnnunciFormatException
	{
		StringReader reader = new StringReader(
				"13/09/2011 : A20688191: trilocale: A5: monolocale interno con angolo cottura, un bagno, termo autonomo: saffi: bologna: 77000\n");
		
		new MyAnnunciReader().read(reader);
	}
		
	@Test(expected=AnnunciFormatException.class)
	public void testReadFail4() throws IOException, AnnunciFormatException
	{
		StringReader reader = new StringReader(
				"13/09/2011 : A20688191: trilocale: 25: monolocale interno con angolo cottura, un bagno, termo autonomo: saffi: bologna: 7A000\n");
		
		new MyAnnunciReader().read(reader);
	}
}
